@@ -8,10 +8,11 @@
     cat(package.description("geoR", lib = lib, field="Title"))
     cat("\n")
     ver <- package.description("geoR", lib = lib, field="Version")
-    cat(paste("geoR version", ver,  "is now loaded\n"))
+    dat <- package.description("geoR", lib = lib, field="Date")
+    cat(paste("geoR version ", ver," (", dat, ") is now loaded\n", sep=""))
   }
   else{
-    cat("geoS: a package for geostatistical analysis in R\n")
+    cat("geoS: a package for geostatistical analysis in S-PLUS\n")
     cat("geoS is now loaded\n")
   }
   cat("-------------------------------------------------\n")
